==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/core/src/main/java/org/apache/servicecomb/core/provider/producer/ProducerMeta.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.core.provider.producer;

public class ProducerMeta {
  private String schemaId;

  private Object instance;

  // 因为aop的存在，instance的class不一定等于instanceClass
  private Class<?> instanceClass;

  public ProducerMeta() {
  }

  public ProducerMeta(String schemaId, Object instance, Class<?> instanceClass) {
    this.schemaId = schemaId;
    this.instance = instance;
    this.instanceClass = instanceClass;
  }

  public String getSchemaId() {
    return schemaId;
  }

  public void setSchemaId(String schemaId) {
    this.schemaId = schemaId;
  }

  public Object getInstance() {
    return instance;
  }

  public void setInstance(Object instance) {
    this.instance = instance;
  }

  public Class<?> getInstanceClass() {
    return instanceClass;
  }

  public void setInstanceClass(Class<?> instanceClass) {
    this.instanceClass = instanceClass;
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.27-src.zip: apache-servicecomb-java-chassis-distribution-2.8.27-src/core/src/main/java/org/apache/servicecomb/core/provider/producer/ProducerMeta.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.core.provider.producer;

public class ProducerMeta {
  private String schemaId;

  private Object instance;

  private Class<?> schemaInterface;

  public ProducerMeta() {
  }

  public ProducerMeta(String schemaId, Object instance) {
    this.schemaId = schemaId;
    this.instance = instance;
  }

  public String getSchemaId() {
    return schemaId;
  }

  public void setSchemaId(String schemaId) {
    this.schemaId = schemaId;
  }

  public Object getInstance() {
    return instance;
  }

  public void setInstance(Object instance) {
    this.instance = instance;
  }

  public Class<?> getSchemaInterface() {
    return schemaInterface;
  }

  public void setSchemaInterface(Class<?> schemaInterface) {
    this.schemaInterface = schemaInterface;
  }
}
